########################################################################################################################################################
# Written by  	: Catherine J Pink
#
# Created on  	: 21/11/2007 (As part of MMBIntrons work)
# Modified on 	: 08/05/2009 (Change of directory names and script structure to fit in with current analysis)
#							 (Removal of counts to be output to information file)
# 						     
# Input files 	: "HMD_Rat5.rpt" (Downloaded from MGI database)
#					
# Output files  : orthologsMGI_Entrez.txt
#				  
# From the input HMD_Rat5.rpt input file, extract the list of orthologous genes (After file annotation and column headings)
# For each row of the list, split by column (tab) into a series of sublists and extract items corresponding to the mouse and rat gene IDs
# If both mouse and rat Entrez gene IDs are present, send pair of orthologous gene IDs to output file.
#
# Procedure to extract ortholog EntrezGene IDs from HMD data file 
########################################################################################################################################################

package provide INTRONS03_orthologlist 1.0

proc INTRONS03_orthologlist {} {

	puts "-----------------------------------------------------------"
	puts "03 EXTRACT ORTHOLOGOUS ENTREZ GENE IDS FROM MGI DATABASE   \n"

	# Make variables global so they can be accessed outside the procedure
	global contents
	
	# Open MGI ortholog file from within Input_Files directory
	cd Input_Files
	openfile HMD_Rat5.rpt
	cd ..

	# Separate annotation and list of orthologs
	# Identify the position of the last "Attributes"
	set lastAttributes [string last Attributes $contents]
	set lineafterAttributes [string first \n $contents $lastAttributes]
	# Extract the datalists from the last Attributes to the end of the document 
	set datalist [string range $contents [expr $lineafterAttributes +1] end]

	# Unset variables
	unset lastAttributes lineafterAttributes contents

	# Split the list around each new line into a series of sublists
	set datalist [split $datalist \n]
	set datalist [lreplace $datalist 0 0]

	# Create an output file to store the list of ortholog pairs
	set out [open orthologsMGI_Entrez.txt w]

	# Work through each sublist in turn to extract 	EntrezGene IDs
	foreach row $datalist {
		set orthsublist [split $row \t]
		set mouseENTREZ [lindex $orthsublist 6]
		set ratENTREZ [lindex $orthsublist 1]
		
		# Determine that both the extracted values contain numerical characters
		if {[regexp {[0-9]+} $mouseENTREZ all] & [regexp {[0-9]+} $ratENTREZ all]} {
			# Export the pair of ortholog EntrezGene IDs to file
			puts $out "$mouseENTREZ\t$ratENTREZ"
		} 
		# Unset variables
		unset orthsublist mouseENTREZ ratENTREZ
	}
	unset row datalist
	
	# Close the output file and move it to the Introns_Data directory
	close $out
	unset out 
	exec mv orthologsMGI_Entrez.txt Intron_Data/orthologsMGI_Entrez.txt
	
	# Unset variables
	unset all
	
	puts "\nVariables still open in INTRONS03_orthologlist : [info local]"
	
return
}