########################################################################################################################################################
# Written by  	: Catherine J Pink
#
# Created on  	: 12/05/2009
# Modified on 	: 13/05/2009 (Completion of script)
#
# Input files 	: Procedure receives 2 alignments when the procedure is called.				  
#				  
# Output files  : Procedure hands back an answer to the test.
#				  This is stored in the variable 'parameter2' and is either 'passed' or 'failed'
#				  
# The script works through each position in the alignment (after checking they are the same length).
# At each position it asks if either position is '-' (an indel).
# The number of aligned bases is counted.
# The script then uses regsub to determine the number of indels and determines the number of indels in both alignments.
# The ratio of the number of indels compared to the number of aligned bases is determined
# This ratio is compared to the critical value of 0.084 (Chamary et al 2004).
# Ratios exceeding 0.008 are deemed to have failed the alignment parameter.
# A variable 'parameter1' is handed back to the previous environment as either 'passed' or 'failed'
#
########################################################################################################################################################

package provide INTRONS11_parameter2 1.0

proc INTRONS11_parameter2 {alignment1 alignment2} {
	
	# Make output variable global
	global parameter2
	global ratio2
	global numberindels1
	global numberindels2
	global numberindels	
	
	# Determine alignment length (and format as floating point integer for ratio calculation)
	if {[string length $alignment1] != [string length $alignment2]} {
		puts "ERROR...$alignmentfile alignments not the same length"
		exit
	}
	
	# Determine number of aligned bases
	set numberalignedbases 0
	for {set i 0} {$i < [string length $alignment1]} {incr i} {
   	   	# If neither character at the same position is an indel, this position contains aligned nucleotides
	   	if {[string index $alignment1 $i] != "-" && [string index $alignment2 $i] != "-"} {
			incr numberalignedbases
	   	}
	}
	unset i
	
	# Determine number of indels (and format as floating point integer for ratio calculation)
	set numberindels1 [regsub -all {[-]+} $alignment1 "" ignore]
	set numberindels2 [regsub -all {[-]+} $alignment2 "" ignore]
	
	set numberindels [format %f [expr {$numberindels1 + $numberindels2}]]
	
	# Determine ratio of number of indels to number of aligned bases
	set ratio2 [expr {$numberindels / $numberalignedbases}]
		
	# Compare ratio to critial parameter value
	if {$ratio2 > 0.084} {
		set parameter2 failed
	} else {
		set parameter2 passed
	}
		
	# Unset variables
	unset numberalignedbases ignore	
 
return
}